Documentation
¶
Index ¶
- func GameInstallSelectors(cmd *cobra.Command, toComplete string) ([]string, cobra.ShellCompDirective)
- func ModFileVersionIDs(cmd *cobra.Command, toComplete string) ([]string, cobra.ShellCompDirective)
- func ModFileVersionIDsForPage(cmd *cobra.Command, modPageArg string, toComplete string) ([]string, cobra.ShellCompDirective)
- func ModPageIDs(cmd *cobra.Command, toComplete string) ([]string, cobra.ShellCompDirective)
- func ProfileNames(cmd *cobra.Command, toComplete string) ([]string, cobra.ShellCompDirective)
- func StoreIDs(cmd *cobra.Command, toComplete string) ([]string, cobra.ShellCompDirective)
- func TargetNames(cmd *cobra.Command, toComplete string) ([]string, cobra.ShellCompDirective)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GameInstallSelectors ¶
func GameInstallSelectors(cmd *cobra.Command, toComplete string) ([]string, cobra.ShellCompDirective)
GameInstallSelectors completes "games set-active <selector>". It returns *full selectors* (always includes #instance) with a description.
func ModFileVersionIDs ¶
ModFileVersionIDs completes mod file version IDs for the active (or --game-scoped) game install. Returns candidates as numeric IDs with a "Mod Page › File Label (version)" description.
func ModFileVersionIDsForPage ¶ added in v0.2.0
func ModFileVersionIDsForPage(cmd *cobra.Command, modPageArg string, toComplete string) ([]string, cobra.ShellCompDirective)
ModFileVersionIDsForPage completes mod file version IDs filtered to a specific mod page. modPageArg may be a numeric ID or a name; if it is non-empty and cannot be resolved unambiguously, no completions are returned. Returns candidates as numeric IDs with a "File Label (version)" description.
func ModPageIDs ¶
ModPageIDs completes mod page IDs for the active (or --game-scoped) game install. Returns candidates as numeric IDs with the mod page name and source kind as the description.
func ProfileNames ¶
ProfileNames completes profile names for the current game install. If the command has a --game flag set, it is used; otherwise the active game is used.
N.B. that at the moment we're using Flags() on all of the profile commands
individually (instead of PersistentFlags() on the profiles root command) which means if we ever switch to PersistentFlags we need to update here to use cmd.InheritedFlags() instead of cmd.Flags().
Returns candidates in "name\t(active)" format.
func StoreIDs ¶
StoreIDs completes (enabled) store IDs Returns candidates in "id\tDisplay Name" format.
func TargetNames ¶ added in v0.6.0
TargetNames completes target names for the current game install. If the command has a --game flag set, it is used; otherwise the active game is used.
Returns candidates in "name\troot_path" format so the user can see where each target points without having to run a separate command.
Types ¶
This section is empty.