Documentation
¶
Overview ¶
Package patchapply applies structured patch entries to ini, yaml, and json files. It is used by the apply pipeline and the patch preview command.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Entry ¶
type Entry struct {
PatchType string // ini_set, ini_unset, yaml_set, yaml_unset, json_set, json_unset, xml_clear, xml_set, xml_unset
EntrySection string // ini only, may be empty
EntryKey string
EntryValue string // empty for unset operations
}
Entry represents a single patch operation to apply
type Result ¶
type Result struct {
Output []byte
Applied int // number of entries successfully applied
Skipped int // number of entries that had no effect (key not found for unset)
}
Result is the outcome of applying a set of patch entries to a file
Click to show internal directories.
Click to hide internal directories.