Documentation
¶
Index ¶
- func SetupDB(t *testing.T) *sql.DB
- type GameBuilder
- func (b *GameBuilder) Build() dbq.GameInstall
- func (b *GameBuilder) NotPresent() *GameBuilder
- func (b *GameBuilder) WithInstallRoot(root string) *GameBuilder
- func (b *GameBuilder) WithInstanceID(id string) *GameBuilder
- func (b *GameBuilder) WithName(name string) *GameBuilder
- func (b *GameBuilder) WithStore(storeID string) *GameBuilder
- func (b *GameBuilder) WithStoreGameID(id string) *GameBuilder
- type ProfileBuilder
- type StoreBuilder
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type GameBuilder ¶
type GameBuilder struct {
// contains filtered or unexported fields
}
GameBuilder builds a game_install row, creating a store if one is not provided
func (*GameBuilder) Build ¶
func (b *GameBuilder) Build() dbq.GameInstall
func (*GameBuilder) NotPresent ¶
func (b *GameBuilder) NotPresent() *GameBuilder
func (*GameBuilder) WithInstallRoot ¶
func (b *GameBuilder) WithInstallRoot(root string) *GameBuilder
func (*GameBuilder) WithInstanceID ¶
func (b *GameBuilder) WithInstanceID(id string) *GameBuilder
func (*GameBuilder) WithName ¶
func (b *GameBuilder) WithName(name string) *GameBuilder
func (*GameBuilder) WithStore ¶
func (b *GameBuilder) WithStore(storeID string) *GameBuilder
func (*GameBuilder) WithStoreGameID ¶
func (b *GameBuilder) WithStoreGameID(id string) *GameBuilder
type ProfileBuilder ¶
type ProfileBuilder struct {
// contains filtered or unexported fields
}
ProfileBuilder builds a profile row for a game install.
func NewProfile ¶
func NewProfile(t *testing.T, db *sql.DB) *ProfileBuilder
func (*ProfileBuilder) Active ¶
func (b *ProfileBuilder) Active() *ProfileBuilder
func (*ProfileBuilder) Build ¶
func (b *ProfileBuilder) Build() dbq.Profile
func (*ProfileBuilder) WithGame ¶
func (b *ProfileBuilder) WithGame(gi dbq.GameInstall) *ProfileBuilder
func (*ProfileBuilder) WithName ¶
func (b *ProfileBuilder) WithName(name string) *ProfileBuilder
type StoreBuilder ¶
type StoreBuilder struct {
// contains filtered or unexported fields
}
StoreBuilder builds a store row
func (*StoreBuilder) Build ¶
func (b *StoreBuilder) Build() dbq.Store
func (*StoreBuilder) WithID ¶
func (b *StoreBuilder) WithID(id string) *StoreBuilder
func (*StoreBuilder) WithImplementation ¶
func (b *StoreBuilder) WithImplementation(impl string) *StoreBuilder
Click to show internal directories.
Click to hide internal directories.